leaftools.get_nth_leaf_in_thread_from_leaf
==========================================

.. autofunction:: abjad.tools.leaftools.get_nth_leaf_in_thread_from_leaf.get_nth_leaf_in_thread_from_leaf
   :noindex:
